"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.creator = exports.messages = void 0;
const secp256k1_1 = __importDefault(require("secp256k1"));
const bn_js_1 = __importDefault(require("bn.js"));
exports.messages = {
    secp256k1Priv: {
        en: (props) => `found secp256k1 private key: ${props.KEY}`,
        ja: (props) => `秘密鍵(secp256k1) ${props.KEY} が見つかりました`,
    },
};
exports.creator = {
    messages: exports.messages,
    meta: {
        id: "@secretlint/secretlint-rule-secp256k1-privatekey",
        recommended: false,
        type: "scanner",
        supportedContentTypes: ["text"],
        docs: {
            url: "https://github.com/secretlint/secretlint/blob/master/packages/%40secretlint/secretlint-rule-secp256k1-privatekey/README.md",
        },
    },
    create(context) {
        const t = context.createTranslator(exports.messages);
        return {
            file(source) {
                const pattern = /[0-9a-f]{64}/gi;
                let match;
                while ((match = pattern.exec(source.content)) !== null) {
                    const index = match.index || 0;
                    const matchString = match[0] || "";
                    const range = [index, index + matchString.length];
                    try {
                        if (!secp256k1_1.default.privateKeyVerify(new bn_js_1.default(matchString, 16).toBuffer()))
                            return;
                        context.report({
                            message: t("secp256k1Priv", {
                                KEY: matchString,
                            }),
                            range,
                        });
                    }
                    catch (error) {
                        // No-op. Not a private key.
                    }
                }
            },
        };
    },
};
exports.default = exports.creator;
//# sourceMappingURL=index.js.map